==> haskell-tuple-0.3.0.2-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-6saBzYNzTjSALIYUDp4B5n
key:                  tuple-0.3.0.2-6saBzYNzTjSALIYUDp4B5n
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  d352a8792827a220b00d1aa8369a435d
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-6saBzYNzTjSALIYUDp4B5n
depends:              OneTuple-0.4.1.1-IVAEQWZp76d1TVzpZm0ZAR base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tuple-0.3.0.2-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-FLU5BpI8PVVFx8vOGtRjH5
key:                  tuple-0.3.0.2-FLU5BpI8PVVFx8vOGtRjH5
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  094fb672148010a30c41df0ab16df7ec
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-FLU5BpI8PVVFx8vOGtRjH5
depends:              OneTuple-0.4.1.1-LakrX5uoHbwz8SCarqPdB base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
